==> bitcream-gmv-ricambi-v0.4-187824.zip: backend/config/params.php <==
<?php
return [
    'adminEmail' => 'admin@example.com',
    'maxImagesGallery' => '4',
    'maxFiles' => '4',
    'userProfile' => false,
    'menuItems' => [
        [   
            'label' => Yii::t('app', 'Dashboard'),
            'url' => ['/'],
            'icon' => 'fontawesome fa fa-tachometer',
        ],   
        [   
            'label' => Yii::t('app', 'GMV Province'),
            'url' => ['/custom/gmv-province/index'],
            'icon' => 'fontawesome fa fa-th',
        ],  
        [   
            'label' => Yii::t('app', 'GMV Customer'),
            'url' => ['/custom/gmv-customer/index'],
            'icon' => 'fontawesome fa fa-th',
        ],  
        [   
            'label' => Yii::t('app', 'GMV Country'),
            'url' => ['/custom/gmv-country/index'],
            'icon' => 'fontawesome fa fa-th',
        ],  
        [   
            'label' => Yii::t('app', 'GMV List'),
            'url' => ['/custom/gmv-list/index'],
            'icon' => 'fontawesome fa fa-th',
        ],  
        [   
            'label' => Yii::t('app', 'GMV Agent'),
            'url' => ['/custom/gmv-agent/index'],
            'icon' => 'fontawesome fa fa-th',
        ],  
        [   
            'label' => Yii::t('app', 'GMV Article'),
            'url' => ['/custom/gmv-article/index'],
            'icon' => 'fontawesome fa fa-th',
        ],
        [   
            'label' => Yii::t('app', 'GMV Article Category'),
            'url' => ['/custom/gmv-articles-category/index'],
            'icon' => 'fontawesome fa fa-th',
        ],
        [   
            'label' => Yii::t('app', 'GMV Assembled Article'),
            'url' => ['/custom/gmv-assembled-article/index'],
            'icon' => 'fontawesome fa fa-th',
        ],
        [   
            'label' => Yii::t('app', 'GMV Discount'),
            'url' => ['/custom/gmv-discount/index'],
            'icon' => 'fontawesome fa fa-th',
        ], 
        [   
            'label' => Yii::t('app', 'GMV Order'),
            'url' => ['/custom/gmv-order/index'],
            'icon' => 'fontawesome fa fa-th',
        ], 
        [   
            'label' => Yii::t('app', 'GMV Payment Method'),
            'url' => ['/custom/gmv-payment-method/index'],
            'icon' => 'fontawesome fa fa-th',
        ],
       [   
            'label' => Yii::t('app', 'GMV Shipping Address'),
            'url' => ['/custom/gmv-shipping-address/index'],
            'icon' => 'fontawesome fa fa-th',
        ], 
        [   
            'label' => Yii::t('app', 'Order'),
            'url' => ['/custom/order/index'],
            'icon' => 'fontawesome fa fa-th',
        ],   
        [   
            'label' => Yii::t('app', 'Order item'),
            'url' => ['/custom/order-item/index'],
            'icon' => 'fontawesome fa fa-th',
        ],
        [   
            'label' => Yii::t('app', 'Product'),
            'url' => ['/custom/product/index'],
            'icon' => 'fontawesome fa fa-th',
        ],
        [
            'label' => Yii::t('app', 'User partner'),
            'url' => ['/custom/user-partner/index'],
            'icon' => 'fontawesome fa fa-th',
        ],
        [
            'label' => Yii::t('app', 'Customer User'),
            'url' => ['/custom/customer-user/index'],
            'icon' => 'fontawesome fa fa-th',
        ],
    ],
'menuPartner' =>  [
        ['label' => 'Il Catalogo', 'options' => ['class' => 'header']],
        [
            'label' => Yii::t('app', 'Product user'),
            'url' => ['/custom/product/index-my'],
            'icon' => 'fontawesome fa fa-th',
        ],
        ['label' => 'Il Tuoi Contenuti', 'options' => ['class' => 'header']],
        [
            'label' => Yii::t('app', 'Customer Info'),
            'url' => ['/custom/gmv-customer/business-info'],
            'icon' => 'fontawesome fa fa-th',
        ],
        [
            'label' => Yii::t('app', 'Payment Info'),
            'url' => ['/custom/gmv-customer/payment-info'],
            'icon' => 'fontawesome fa fa-th',
        ],
        [
            'label' => Yii::t('app', 'Agent Info'),
            'url' => ['/custom/gmv-agent/agent-info'],
            'icon' => 'fontawesome fa fa-th',
        ],
        [
            'label' => Yii::t('app', 'Order client'),
            'url' => ['/custom/order/index-my'],
            'icon' => 'fontawesome fa fa-th',
        ],
        [
            'label' => Yii::t('app', 'Shipping Info'),
            'url' => ['/custom/gmv-shipping-address/index-my'],
            'icon' => 'fontawesome fa fa-th',
        ],
    ]

];

==> bitcream-gmv-ricambi-v0.5.1-726b15.zip: backend/config/params.php <==
<?php
return [
    'adminEmail' => 'admin@example.com',
    'maxImagesGallery' => '4',
    'maxFiles' => '4',
    'userProfile' => false,
    'menuItems' => [
        [   
            'label' => Yii::t('app', 'Dashboard'),
            'url' => ['/'],
            'icon' => 'fontawesome fa fa-tachometer',
        ],   
        [   
            'label' => Yii::t('app', 'GMV Province'),
            'url' => ['/custom/gmv-province/index'],
            'icon' => 'fontawesome fa fa-th',
        ],  
        [   
            'label' => Yii::t('app', 'GMV Customer'),
            'url' => ['/custom/gmv-customer/index'],
            'icon' => 'fontawesome fa fa-th',
        ],  
        [   
            'label' => Yii::t('app', 'GMV Country'),
            'url' => ['/custom/gmv-country/index'],
            'icon' => 'fontawesome fa fa-th',
        ],  
        [   
            'label' => Yii::t('app', 'GMV List'),
            'url' => ['/custom/gmv-list/index'],
            'icon' => 'fontawesome fa fa-th',
        ],  
        [   
            'label' => Yii::t('app', 'GMV Agent'),
            'url' => ['/custom/gmv-agent/index'],
            'icon' => 'fontawesome fa fa-th',
        ],  
        [   
            'label' => Yii::t('app', 'GMV Article'),
            'url' => ['/custom/gmv-article/index'],
            'icon' => 'fontawesome fa fa-th',
        ],
        [   
            'label' => Yii::t('app', 'GMV Article Category'),
            'url' => ['/custom/gmv-articles-category/index'],
            'icon' => 'fontawesome fa fa-th',
        ],
        [   
            'label' => Yii::t('app', 'GMV Assembled Article'),
            'url' => ['/custom/gmv-assembled-article/index'],
            'icon' => 'fontawesome fa fa-th',
        ],
        [   
            'label' => Yii::t('app', 'GMV Discount'),
            'url' => ['/custom/gmv-discount/index'],
            'icon' => 'fontawesome fa fa-th',
        ], 
        [   
            'label' => Yii::t('app', 'GMV Order'),
            'url' => ['/custom/gmv-order/index'],
            'icon' => 'fontawesome fa fa-th',
        ], 
        [   
            'label' => Yii::t('app', 'GMV Payment Method'),
            'url' => ['/custom/gmv-payment-method/index'],
            'icon' => 'fontawesome fa fa-th',
        ],
       [   
            'label' => Yii::t('app', 'GMV Shipping Address'),
            'url' => ['/custom/gmv-shipping-address/index'],
            'icon' => 'fontawesome fa fa-th',
        ], 
        [   
            'label' => Yii::t('app', 'Order'),
            'url' => ['/custom/order/index'],
            'icon' => 'fontawesome fa fa-th',
        ],   
        [   
            'label' => Yii::t('app', 'Order item'),
            'url' => ['/custom/order-item/index'],
            'icon' => 'fontawesome fa fa-th',
        ],
        [
            'label' => Yii::t('app', 'User partner'),
            'url' => ['/custom/user-partner/index'],
            'icon' => 'fontawesome fa fa-th',
        ],
        [
            'label' => Yii::t('app', 'Customer User'),
            'url' => ['/custom/customer-user/index'],
            'icon' => 'fontawesome fa fa-th',
        ],
    ],
'menuPartner' =>  [
        ['label' => 'Il Catalogo', 'options' => ['class' => 'header']],
        [
            'label' => Yii::t('app', 'Products'),
            'url' => ['/custom/product/index-my'],
            'icon' => 'fontawesome fa fa-th',
        ],
        ['label' => 'Il Tuoi Contenuti', 'options' => ['class' => 'header']],
        [
            'label' => Yii::t('app', 'Customer Info'),
            'url' => ['/custom/gmv-customer/business-info'],
            'icon' => 'fontawesome fa fa-th',
        ],
        [
            'label' => Yii::t('app', 'Payment Info'),
            'url' => ['/custom/gmv-customer/payment-info'],
            'icon' => 'fontawesome fa fa-th',
        ],
        [
            'label' => Yii::t('app', 'Agent Info'),
            'url' => ['/custom/gmv-agent/agent-info'],
            'icon' => 'fontawesome fa fa-th',
        ],
        [
            'label' => Yii::t('app', 'Orders'),
            'url' => ['/custom/order-customer/index'],
            'icon' => 'fontawesome fa fa-th',
        ],
        [
            'label' => Yii::t('app', 'Shipping Info'),
            'url' => ['/custom/gmv-shipping-address/index-my'],
            'icon' => 'fontawesome fa fa-th',
        ],
    ]

];
